#ifndef SVN_POOL_HH
#define SVN_POOL_HH

#include <apr/pool.hh>

namespace svn {

class Pool : public apr::Pool {
    public:
        /**
         * Creates a new global pool.
         * An error pool will be created.
         *
         * <p>If anything goes wrong with the pool creation, an abort function
         * will be called, which will exit the program. If future allocations
         * from this pool cannot be fulfilled, then the abort functions will
         * be called, terminating the program.</p>
         **/
        Pool();

        /**
         * Creates a new subpool.
         * Inherits the containing pool's dedicated error subpool.
         *
         * <p>If anything goes wrong with the pool creation, an abort function
         * will be called, which will exit the program. If future allocations
         * from this pool cannot be fulfilled, then the abort functions will
         * be called, terminating the program.</p>
         **/
        Pool(Pool &parent);

        /** Wraps a C reference. **/
        explicit Pool(apr_pool_t *pool) : apr::Pool(pool) {}

        /**
         * Clears the pool.
         * apr::Pool::clear() removes the association with the appropriate
         * error pool. This clears the pool and reattaches or recreates the
         * error pool.
         **/
        void clear();

        ~Pool();
};

}

#endif
