#ifndef SVN_WC_HH
#define SVN_WC_HH

#include <svn/types.hh>

namespace svn {
namespace wc {

enum NotifyAction {
    nAdd = svn_wc_notify_add,
    nCopy = svn_wc_notify_copy,
    nDelete = svn_wc_notify_delete,
    nRevert = svn_wc_notify_revert,
    nResolve = svn_wc_notify_resolve,

    /// Got a delete in an update
    nUpdateDelete = svn_wc_notify_update_delete,

    /// Got an add in an update
    nUpdateAdd = svn_wc_notify_update_add,

    /// Got any other action in an update
    nUpdateUpdate = svn_wc_notify_update_update,

    /// The last notification in an update
    nUpdateCompleted = svn_wc_notify_update_completed,

    /** About to update an external module; use for checkouts and switches,
     * too, end with nUpdateCompleted. */
    nUpdateExternal = svn_wc_notify_update_external,

    nCommitModified = svn_wc_notify_commit_modified,
    nCommitAdded = svn_wc_notify_commit_added,
    nCommitDeleted = svn_wc_notify_commit_deleted,
    nCommitPostfixTxdelta = svn_wc_notify_commit_postfix_txdelta
};

/** @see svn_wc_notify_state_t **/
enum NotifyState {
    sInapplicable = svn_wc_notify_state_inapplicable,
    sUnknown = svn_wc_notify_state_unknown,
    sUnchanged = svn_wc_notify_state_unchanged,
    sChanged = svn_wc_notify_state_changed,
    sMerged = svn_wc_notify_state_merged,
    sConflicted = svn_wc_notify_state_conflicted
};

/**
 * Arguments for a single call of the notification function.
 * Expanded in a structure to avoid duplicating long lists of arguments and
 * for documentation purposes.
 **/
struct Notification {
    /**
     * Path of the changed node.
     * May be absolute or relative to the current working directory (i.e.,
     * not relative to an anchor).
     **/
    std::string path;

    NotifyAction action;

    /// The kind of node after the action.
    NodeKind kind;

    /**
     * If non-null, the MIME type of the file.
     * Always null for directories.
     **/
    std::string mimeType;

    NotifyState contentState;
    NotifyState propertiesState;
    RevisionNumber revision;
};

}
}
#endif //!SVN_WC_HH
